CONFIG_DATA = {
    'active': 'VA-000',
    'accounts': [
        {
            'id': 'VA-000',
            'name': 'Account 0',
            'api_key': 'ApiKey XXXX:YYYY',
            'endpoint': 'https://localhost/public/v1',
        },
        {
            'id': 'VA-001',
            'name': 'Account 1',
            'api_key': 'ApiKey ZZZZ:SSSS',
            'endpoint': 'https://localhost/public/v1',
        }
    ],
}